@@ -42,15 +42,6 @@
 #define EEL_STANDARD_CLOSE_WINDOW_CONTROL_KEY 	'w'
 
 /* signals */
-guint                 eel_gtk_signal_connect_free_data                (GtkObject            *object,
-								       const gchar          *name,
-								       GtkSignalFunc         func,
-								       gpointer              data);
-guint                 eel_gtk_signal_connect_free_data_custom         (GtkObject            *object,
-								       const gchar          *name,
-								       GtkSignalFunc         func,
-								       gpointer              data,
-								       GtkDestroyNotify      destroy_func);
 void                  eel_gtk_signal_connect_full_while_alive         (GtkObject            *object,
 								       const gchar          *name,
 								       GtkSignalFunc         func,
